@@ -6,7 +6,7 @@
 CKEDITOR.plugins.setLang( 'placeholder', 'lv', {
 	title: 'Viettura uzstādījumi',
 	toolbar: 'Izveidot vietturi',
-	name: 'Placeholder Name', // MISSING
-	invalidName: 'The placeholder can not be empty and can not contain any of following characters: [, ], <, >', // MISSING
-	pathName: 'placeholder' // MISSING
+	name: 'Viettura nosaukums',
+	invalidName: 'Vietturis nevar būt tukšs un nevar saturēt simbolus [, ], <, >',
+	pathName: 'vietturis'
 } );
